@@ -186,16 +186,20 @@ class CLS(AbstractModel):
         :type LogSet: str
         :param Topic: 日志主题
         :type Topic: str
+        :param NeedDelete: 是否删除
+        :type NeedDelete: bool
         """
         self.Enable = None
         self.LogSet = None
         self.Topic = None
+        self.NeedDelete = None
 
 
     def _deserialize(self, params):
         self.Enable = params.get("Enable")
         self.LogSet = params.get("LogSet")
         self.Topic = params.get("Topic")
+        self.NeedDelete = params.get("NeedDelete")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -379,6 +383,90 @@ class ClusterStatus(AbstractModel):
         
 
 
+class CreateMeshRequest(AbstractModel):
+    """CreateMesh请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DisplayName: Mesh名称
+        :type DisplayName: str
+        :param MeshVersion: Mesh版本
+        :type MeshVersion: str
+        :param Type: Mesh类型，取值范围：
+- HOSTED：托管网格
+        :type Type: str
+        :param Config: Mesh配置
+        :type Config: :class:`tencentcloud.tcm.v20210413.models.MeshConfig`
+        :param ClusterList: 关联集群
+        :type ClusterList: list of Cluster
+        :param TagList: 标签列表
+        :type TagList: list of Tag
+        """
+        self.DisplayName = None
+        self.MeshVersion = None
+        self.Type = None
+        self.Config = None
+        self.ClusterList = None
+        self.TagList = None
+
+
+    def _deserialize(self, params):
+        self.DisplayName = params.get("DisplayName")
+        self.MeshVersion = params.get("MeshVersion")
+        self.Type = params.get("Type")
+        if params.get("Config") is not None:
+            self.Config = MeshConfig()
+            self.Config._deserialize(params.get("Config"))
+        if params.get("ClusterList") is not None:
+            self.ClusterList = []
+            for item in params.get("ClusterList"):
+                obj = Cluster()
+                obj._deserialize(item)
+                self.ClusterList.append(obj)
+        if params.get("TagList") is not None:
+            self.TagList = []
+            for item in params.get("TagList"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.TagList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateMeshResponse(AbstractModel):
+    """CreateMesh返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: 创建的Mesh的Id
+        :type MeshId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.MeshId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.RequestId = params.get("RequestId")
+
+
+class CrossRegionConfig(AbstractModel):
+    """负载均衡跨域设置
+
+    """
+
+
 class CustomPromConfig(AbstractModel):
     """第三方 Prometheus 配置参数
 
@@ -423,6 +511,63 @@ class CustomPromConfig(AbstractModel):
         
 
 
+class DeleteMeshRequest(AbstractModel):
+    """DeleteMesh请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: 需要删除的MeshId
+        :type MeshId: str
+        :param NeedDeleteCLS: CLS组件是否被删除
+        :type NeedDeleteCLS: bool
+        :param NeedDeleteTMP: TMP组件是否被删除
+        :type NeedDeleteTMP: bool
+        :param NeedDeleteAPM: APM组件是否被删除
+        :type NeedDeleteAPM: bool
+        :param NeedDeleteGrafana: Grafana组件是否被删除
+        :type NeedDeleteGrafana: bool
+        """
+        self.MeshId = None
+        self.NeedDeleteCLS = None
+        self.NeedDeleteTMP = None
+        self.NeedDeleteAPM = None
+        self.NeedDeleteGrafana = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.NeedDeleteCLS = params.get("NeedDeleteCLS")
+        self.NeedDeleteTMP = params.get("NeedDeleteTMP")
+        self.NeedDeleteAPM = params.get("NeedDeleteAPM")
+        self.NeedDeleteGrafana = params.get("NeedDeleteGrafana")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeleteMeshResponse(AbstractModel):
+    """DeleteMesh返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeployConfig(AbstractModel):
     """部署配置
 
@@ -453,6 +598,93 @@ class DeployConfig(AbstractModel):
         
 
 
+class DescribeAccessLogConfigRequest(AbstractModel):
+    """DescribeAccessLogConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh名字
+        :type MeshId: str
+        """
+        self.MeshId = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeAccessLogConfigResponse(AbstractModel):
+    """DescribeAccessLogConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param File: 访问日志输出路径。默认 /dev/stdout
+        :type File: str
+        :param Format: 访问日志的格式。
+        :type Format: str
+        :param Encoding: 访问日志输出编码，可取值为 "TEXT" 或 "JSON"，默认 TEXT"
+        :type Encoding: str
+        :param SelectedRange: 选中的范围
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SelectedRange: :class:`tencentcloud.tcm.v20210413.models.SelectedRange`
+        :param Template: 采用的模板，可取值为"istio" 或 "trace"，默认为"istio"
+        :type Template: str
+        :param CLS: 腾讯云日志服务相关参数
+        :type CLS: :class:`tencentcloud.tcm.v20210413.models.CLS`
+        :param Address: GRPC第三方服务器地址
+        :type Address: str
+        :param EnableServer: 是否启用GRPC第三方服务器
+        :type EnableServer: bool
+        :param EnableStdout: 是否启用标准输出
+        :type EnableStdout: bool
+        :param Enable: 是否启用访问日志采集
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Enable: bool
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.File = None
+        self.Format = None
+        self.Encoding = None
+        self.SelectedRange = None
+        self.Template = None
+        self.CLS = None
+        self.Address = None
+        self.EnableServer = None
+        self.EnableStdout = None
+        self.Enable = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.File = params.get("File")
+        self.Format = params.get("Format")
+        self.Encoding = params.get("Encoding")
+        if params.get("SelectedRange") is not None:
+            self.SelectedRange = SelectedRange()
+            self.SelectedRange._deserialize(params.get("SelectedRange"))
+        self.Template = params.get("Template")
+        if params.get("CLS") is not None:
+            self.CLS = CLS()
+            self.CLS._deserialize(params.get("CLS"))
+        self.Address = params.get("Address")
+        self.EnableServer = params.get("EnableServer")
+        self.EnableStdout = params.get("EnableStdout")
+        self.Enable = params.get("Enable")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeMeshListRequest(AbstractModel):
     """DescribeMeshList请求参数结构体
 
@@ -581,10 +813,13 @@ class EgressGateway(AbstractModel):
         :type Namespace: str
         :param Workload: 工作负载配置
         :type Workload: :class:`tencentcloud.tcm.v20210413.models.WorkloadConfig`
+        :param Status: 工作负载的状态
+        :type Status: :class:`tencentcloud.tcm.v20210413.models.EgressGatewayStatus`
         """
         self.Name = None
         self.Namespace = None
         self.Workload = None
+        self.Status = None
 
 
     def _deserialize(self, params):
@@ -593,6 +828,41 @@ class EgressGateway(AbstractModel):
         if params.get("Workload") is not None:
             self.Workload = WorkloadConfig()
             self.Workload._deserialize(params.get("Workload"))
+        if params.get("Status") is not None:
+            self.Status = EgressGatewayStatus()
+            self.Status._deserialize(params.get("Status"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class EgressGatewayStatus(AbstractModel):
+    """egress gateway 的状态
+
+    """
+
+    def __init__(self):
+        r"""
+        :param CurrentVersion: egress gateway的当前版本
+        :type CurrentVersion: str
+        :param DesiredVersion: egress gateway的目标版本
+        :type DesiredVersion: str
+        :param State: egress gateway的状态，取值：running，upgrading，rollbacking
+        :type State: str
+        """
+        self.CurrentVersion = None
+        self.DesiredVersion = None
+        self.State = None
+
+
+    def _deserialize(self, params):
+        self.CurrentVersion = params.get("CurrentVersion")
+        self.DesiredVersion = params.get("DesiredVersion")
+        self.State = params.get("State")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -850,14 +1120,26 @@ class IngressGatewayStatus(AbstractModel):
         r"""
         :param LoadBalancer: 负载均衡实例状态
         :type LoadBalancer: :class:`tencentcloud.tcm.v20210413.models.LoadBalancerStatus`
+        :param CurrentVersion: ingress gateway 当前的版本
+        :type CurrentVersion: str
+        :param DesiredVersion: ingress gateway 目标的版本
+        :type DesiredVersion: str
+        :param State: ingress gateway的状态，取值running, upgrading, rollbacking
+        :type State: str
         """
         self.LoadBalancer = None
+        self.CurrentVersion = None
+        self.DesiredVersion = None
+        self.State = None
 
 
     def _deserialize(self, params):
         if params.get("LoadBalancer") is not None:
             self.LoadBalancer = LoadBalancerStatus()
             self.LoadBalancer._deserialize(params.get("LoadBalancer"))
+        self.CurrentVersion = params.get("CurrentVersion")
+        self.DesiredVersion = params.get("DesiredVersion")
+        self.State = params.get("State")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -916,10 +1198,22 @@ class IstioConfig(AbstractModel):
         :param DisablePolicyChecks: 禁用策略检查功能
 注意：此字段可能返回 null，表示取不到有效值。
         :type DisablePolicyChecks: bool
+        :param EnablePilotHTTP: 支持HTTP1.0协议
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EnablePilotHTTP: bool
+        :param DisableHTTPRetry: 禁用HTTP重试策略
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DisableHTTPRetry: bool
+        :param SmartDNS: SmartDNS策略
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SmartDNS: :class:`tencentcloud.tcm.v20210413.models.SmartDNSConfig`
         """
         self.OutboundTrafficPolicy = None
         self.Tracing = None
         self.DisablePolicyChecks = None
+        self.EnablePilotHTTP = None
+        self.DisableHTTPRetry = None
+        self.SmartDNS = None
 
 
     def _deserialize(self, params):
@@ -928,6 +1222,11 @@ class IstioConfig(AbstractModel):
             self.Tracing = TracingConfig()
             self.Tracing._deserialize(params.get("Tracing"))
         self.DisablePolicyChecks = params.get("DisablePolicyChecks")
+        self.EnablePilotHTTP = params.get("EnablePilotHTTP")
+        self.DisableHTTPRetry = params.get("DisableHTTPRetry")
+        if params.get("SmartDNS") is not None:
+            self.SmartDNS = SmartDNSConfig()
+            self.SmartDNS._deserialize(params.get("SmartDNS"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -963,6 +1262,103 @@ class IstiodConfig(AbstractModel):
         
 
 
+class LinkClusterListRequest(AbstractModel):
+    """LinkClusterList请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: 网格Id
+        :type MeshId: str
+        :param ClusterList: 关联集群
+        :type ClusterList: list of Cluster
+        """
+        self.MeshId = None
+        self.ClusterList = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        if params.get("ClusterList") is not None:
+            self.ClusterList = []
+            for item in params.get("ClusterList"):
+                obj = Cluster()
+                obj._deserialize(item)
+                self.ClusterList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class LinkClusterListResponse(AbstractModel):
+    """LinkClusterList返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class LinkPrometheusRequest(AbstractModel):
+    """LinkPrometheus请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshID: 网格ID
+        :type MeshID: str
+        :param Prometheus: 配置
+        :type Prometheus: :class:`tencentcloud.tcm.v20210413.models.PrometheusConfig`
+        """
+        self.MeshID = None
+        self.Prometheus = None
+
+
+    def _deserialize(self, params):
+        self.MeshID = params.get("MeshID")
+        if params.get("Prometheus") is not None:
+            self.Prometheus = PrometheusConfig()
+            self.Prometheus._deserialize(params.get("Prometheus"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class LinkPrometheusResponse(AbstractModel):
+    """LinkPrometheus返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class LoadBalancer(AbstractModel):
     """负载均衡配置
 
@@ -998,6 +1394,9 @@ OPEN：公网属性， INTERNAL：内网属性。
         :param ExtensiveClusters: 内网独占集群配置列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type ExtensiveClusters: :class:`tencentcloud.tcm.v20210413.models.ExtensiveClusters`
+        :param CrossRegionConfig: 负载均衡跨地域配置
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CrossRegionConfig: :class:`tencentcloud.tcm.v20210413.models.CrossRegionConfig`
         """
         self.LoadBalancerType = None
         self.SubnetId = None
@@ -1009,6 +1408,7 @@ OPEN：公网属性， INTERNAL：内网属性。
         self.AddressIPVersion = None
         self.Tags = None
         self.ExtensiveClusters = None
+        self.CrossRegionConfig = None
 
 
     def _deserialize(self, params):
@@ -1029,6 +1429,9 @@ OPEN：公网属性， INTERNAL：内网属性。
         if params.get("ExtensiveClusters") is not None:
             self.ExtensiveClusters = ExtensiveClusters()
             self.ExtensiveClusters._deserialize(params.get("ExtensiveClusters"))
+        if params.get("CrossRegionConfig") is not None:
+            self.CrossRegionConfig = CrossRegionConfig()
+            self.CrossRegionConfig._deserialize(params.get("CrossRegionConfig"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1114,6 +1517,8 @@ class Mesh(AbstractModel):
         :type Config: :class:`tencentcloud.tcm.v20210413.models.MeshConfig`
         :param Status: Mesh详细状态
         :type Status: :class:`tencentcloud.tcm.v20210413.models.MeshStatus`
+        :param TagList: 标签列表
+        :type TagList: list of Tag
         """
         self.MeshId = None
         self.DisplayName = None
@@ -1126,6 +1531,7 @@ class Mesh(AbstractModel):
         self.ClusterList = None
         self.Config = None
         self.Status = None
+        self.TagList = None
 
 
     def _deserialize(self, params):
@@ -1149,6 +1555,12 @@ class Mesh(AbstractModel):
         if params.get("Status") is not None:
             self.Status = MeshStatus()
             self.Status._deserialize(params.get("Status"))
+        if params.get("TagList") is not None:
+            self.TagList = []
+            for item in params.get("TagList"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.TagList.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1314,6 +1726,208 @@ class MetricSpec(AbstractModel):
         
 
 
+class ModifyAccessLogConfigRequest(AbstractModel):
+    """ModifyAccessLogConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh ID
+        :type MeshId: str
+        :param SelectedRange: 选中的范围
+        :type SelectedRange: :class:`tencentcloud.tcm.v20210413.models.SelectedRange`
+        :param Template: 采用的模板，可选值：istio（默认）、trace、custom
+        :type Template: str
+        :param Enable: 是否启用
+        :type Enable: bool
+        :param CLS: 腾讯云日志服务相关参数
+        :type CLS: :class:`tencentcloud.tcm.v20210413.models.CLS`
+        :param Encoding: 编码格式，可选值：TEXT、JSON
+        :type Encoding: str
+        :param Format: 日志格式
+        :type Format: str
+        :param EnableStdout: 是否启用标准输出
+        :type EnableStdout: bool
+        :param EnableServer: 是否启动GRPC第三方服务器
+        :type EnableServer: bool
+        :param Address: GRPC第三方服务器地址
+        :type Address: str
+        """
+        self.MeshId = None
+        self.SelectedRange = None
+        self.Template = None
+        self.Enable = None
+        self.CLS = None
+        self.Encoding = None
+        self.Format = None
+        self.EnableStdout = None
+        self.EnableServer = None
+        self.Address = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        if params.get("SelectedRange") is not None:
+            self.SelectedRange = SelectedRange()
+            self.SelectedRange._deserialize(params.get("SelectedRange"))
+        self.Template = params.get("Template")
+        self.Enable = params.get("Enable")
+        if params.get("CLS") is not None:
+            self.CLS = CLS()
+            self.CLS._deserialize(params.get("CLS"))
+        self.Encoding = params.get("Encoding")
+        self.Format = params.get("Format")
+        self.EnableStdout = params.get("EnableStdout")
+        self.EnableServer = params.get("EnableServer")
+        self.Address = params.get("Address")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyAccessLogConfigResponse(AbstractModel):
+    """ModifyAccessLogConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class ModifyMeshRequest(AbstractModel):
+    """ModifyMesh请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: 需要修改的网格Id
+        :type MeshId: str
+        :param DisplayName: 修改的网格名称
+        :type DisplayName: str
+        :param Config: 修改的网格配置
+        :type Config: :class:`tencentcloud.tcm.v20210413.models.MeshConfig`
+        :param ClusterList: 修改的集群配置
+        :type ClusterList: list of Cluster
+        """
+        self.MeshId = None
+        self.DisplayName = None
+        self.Config = None
+        self.ClusterList = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.DisplayName = params.get("DisplayName")
+        if params.get("Config") is not None:
+            self.Config = MeshConfig()
+            self.Config._deserialize(params.get("Config"))
+        if params.get("ClusterList") is not None:
+            self.ClusterList = []
+            for item in params.get("ClusterList"):
+                obj = Cluster()
+                obj._deserialize(item)
+                self.ClusterList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyMeshResponse(AbstractModel):
+    """ModifyMesh返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class ModifyTracingConfigRequest(AbstractModel):
+    """ModifyTracingConfig请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: mesh名字
+        :type MeshId: str
+        :param Enable: 是否启用调用跟踪
+        :type Enable: bool
+        :param APM: 腾讯云 APM 服务相关参数
+        :type APM: :class:`tencentcloud.tcm.v20210413.models.APM`
+        :param Sampling: 调用跟踪采样值
+        :type Sampling: float
+        :param Zipkin: 调用追踪Zipkin相关配置
+        :type Zipkin: :class:`tencentcloud.tcm.v20210413.models.TracingZipkin`
+        """
+        self.MeshId = None
+        self.Enable = None
+        self.APM = None
+        self.Sampling = None
+        self.Zipkin = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.Enable = params.get("Enable")
+        if params.get("APM") is not None:
+            self.APM = APM()
+            self.APM._deserialize(params.get("APM"))
+        self.Sampling = params.get("Sampling")
+        if params.get("Zipkin") is not None:
+            self.Zipkin = TracingZipkin()
+            self.Zipkin._deserialize(params.get("Zipkin"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyTracingConfigResponse(AbstractModel):
+    """ModifyTracingConfig返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class PodsMetricSource(AbstractModel):
     """PodsMetricSource 定义了如何根据特定指标进行扩缩容
 
@@ -1640,6 +2254,36 @@ class Service(AbstractModel):
         
 
 
+class SmartDNSConfig(AbstractModel):
+    """智能DNS配置
+
+    """
+
+    def __init__(self):
+        r"""
+        :param IstioMetaDNSCapture: 开启DNS代理
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IstioMetaDNSCapture: bool
+        :param IstioMetaDNSAutoAllocate: 开启自动地址分配
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IstioMetaDNSAutoAllocate: bool
+        """
+        self.IstioMetaDNSCapture = None
+        self.IstioMetaDNSAutoAllocate = None
+
+
+    def _deserialize(self, params):
+        self.IstioMetaDNSCapture = params.get("IstioMetaDNSCapture")
+        self.IstioMetaDNSAutoAllocate = params.get("IstioMetaDNSAutoAllocate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Tag(AbstractModel):
     """标签
 
@@ -1736,6 +2380,92 @@ class TracingZipkin(AbstractModel):
         
 
 
+class UnlinkClusterRequest(AbstractModel):
+    """UnlinkCluster请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshId: 网格Id
+        :type MeshId: str
+        :param ClusterId: 取消关联的集群Id
+        :type ClusterId: str
+        """
+        self.MeshId = None
+        self.ClusterId = None
+
+
+    def _deserialize(self, params):
+        self.MeshId = params.get("MeshId")
+        self.ClusterId = params.get("ClusterId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UnlinkClusterResponse(AbstractModel):
+    """UnlinkCluster返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class UnlinkPrometheusRequest(AbstractModel):
+    """UnlinkPrometheus请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MeshID: 网格ID
+        :type MeshID: str
+        """
+        self.MeshID = None
+
+
+    def _deserialize(self, params):
+        self.MeshID = params.get("MeshID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UnlinkPrometheusResponse(AbstractModel):
+    """UnlinkPrometheus返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class WorkloadConfig(AbstractModel):
     """工作负载配置
 
